Bindful

Struct Bindful 

pub struct Bindful<S> { /* private fields */ }
Bindful state: maps variable numbers to values

Implementations

Source

impl<S: Clone> Bindful<S>

pub fn new() -> Self

Create a new empty Bindful state

pub fn next_free(&self) -> i32

Find the next free variable number

pub fn bind(&mut self, n: i32, value: S)

Bind a value to a variable number

pub fn unbind(&mut self, n: i32)

Unbind a variable number

pub fn binding(&self, n: i32) -> Option<S>

Get the value bound to a variable number

pub fn get_values(&self) -> Vec<S>

Get all bound values

pub fn twiddle_bound<F>(&mut self, f: F)
where F: Fn(&S) -> S,

Apply a function to all bound values

pub fn with_binding<R, F>(&mut self, value: S, f: F) -> R
where F: FnOnce(i32, &mut Self) -> R,

Execute a function with a temporary binding, then unbind

pub fn bind_next(&mut self, value: S) -> i32

Bind a value to the next free variable number